"""
Module for keeping exhibit-wide constants
"""

ORIGINAL_VALUES_DB = "Number of unique values is above inline limit"
ORIGINAL_VALUES_PAIRED = "See paired column"
ORIGINAL_VALUES_REGEX = "regex"
MISSING_DATA_STR = "Missing data"